"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CacheThenNetwork = void 0;
const streamer_1 = require("./streamer");
class CacheThenNetwork extends streamer_1.Streamer {
    constructor(plugin, cacheWithCookie = false, ms) {
        super("cache" /* StreamType.CACHE */);
        this.ms = ms;
        this.cacheWithCookie = cacheWithCookie;
        this.storage = plugin;
    }
    onResponse(chunk, next) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            if (!chunk.cacheHit && !chunk.error && chunk.response) {
                if (((_a = chunk.response.headers) === null || _a === void 0 ? void 0 : _a["set-cookie"]) && !this.cacheWithCookie) {
                    console.warn('Detected dangerous response with set-cookie header, not caching', chunk.key);
                }
                else {
                    yield this.storage.set(chunk.key, {
                        headers: chunk.response.headers,
                        statusCode: chunk.response.statusCode,
                        body: chunk.response.body
                    }, this.ms);
                }
            }
            next(chunk);
        });
    }
    onRequest(chunk, next) {
        return __awaiter(this, void 0, void 0, function* () {
            const cachedData = yield this.storage.get(chunk.key);
            if (cachedData) {
                this.respond(Object.assign(Object.assign({}, chunk), { response: cachedData, cacheHit: true }));
            }
            else {
                next(chunk);
            }
        });
    }
}
exports.CacheThenNetwork = CacheThenNetwork;
//# sourceMappingURL=cache-then-network.js.map