"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RequestManager = void 0;
const fast_url_parser_1 = __importDefault(require("fast-url-parser"));
const stream_factory_1 = require("./stream-factory");
const cookie_1 = __importDefault(require("cookie"));
class RequestManager {
    constructor(streamFactory, tokenizer) {
        this.streams = {};
        this.requestId = 0;
        this.tokenizer = tokenizer;
        this.streamFactory = streamFactory;
    }
    register(name, routeConfiguration) {
        const stream = this.streamFactory.createHead();
        let streamLink = stream;
        const network = this.streamFactory.createNetwork(name);
        const keyMaker = this.tokenizer.tokenize(name, routeConfiguration.identifier);
        Object.values(stream_factory_1.ConfigurableStream).forEach((streamType) => {
            const configuration = routeConfiguration[streamType];
            if (configuration) {
                const stream = this.streamFactory.create(streamType, configuration);
                streamLink = streamLink.connect(stream);
            }
        });
        streamLink.connect(network);
        this.addStream(name, {
            keyMaker,
            stream
        });
        return this.handle.bind(this, name);
    }
    unregister(name) {
        delete this.streams[name];
    }
    handle(name, requestOptions, cb) {
        if (!this.streams[name])
            throw new Error(`Route configuration not provided for ${name}`);
        const request = fast_url_parser_1.default.parse(requestOptions.url, true);
        const headers = requestOptions.headers || {};
        const cookies = cookie_1.default.parse(headers.cookie || headers.Cookie || '');
        const key = this.streams[name][0].keyMaker(request.pathname, cookies, headers, request.query, requestOptions.method);
        return this.streams[name][0].stream.start(key, ++this.requestId, requestOptions, cb);
    }
    isRouteRegistered(name) {
        return !!this.streams[name];
    }
    addStream(name, keyStreamPair) {
        (this.streams[name] = this.streams[name] || []).unshift(keyStreamPair);
    }
}
exports.RequestManager = RequestManager;
//# sourceMappingURL=request-manager.js.map