"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Retry = void 0;
const streamer_1 = require("./streamer");
const DEFAULT_RETRY_CONFIGURATION = {
    count: 1,
    delay: 100,
};
const RETRYABLE_ERRORS = ['ECONNRESET', 'ENOTFOUND', 'ESOCKETTIMEDOUT', 'ETIMEDOUT', 'ECONNREFUSED', 'EHOSTUNREACH', 'EPIPE', 'EAI_AGAIN'];
class Retry extends streamer_1.Streamer {
    constructor(configuration) {
        super("retry" /* StreamType.RETRY */);
        this.configuration = configuration;
    }
    static create(configuration) {
        if (typeof configuration === "boolean") {
            return new Retry(DEFAULT_RETRY_CONFIGURATION);
        }
        else if (typeof configuration === "number") {
            return new Retry({
                count: configuration,
                delay: 0
            });
        }
        else if (typeof configuration === "object") {
            const count = configuration.count || 1;
            const delay = configuration.delay || 0;
            return new Retry({
                count,
                delay,
                logger: configuration.logger
            });
        }
        else {
            return new Retry(DEFAULT_RETRY_CONFIGURATION);
        }
    }
    onResponse(chunk, next) {
        return __awaiter(this, void 0, void 0, function* () {
            if (chunk.retryCount <= this.configuration.count && this.shouldRetry(chunk)) {
                if (this.configuration.delay > 0) {
                    setTimeout(() => {
                        this.retry(chunk);
                    }, this.configuration.delay);
                }
                else {
                    this.retry(chunk);
                }
            }
            else {
                next(chunk);
            }
        });
    }
    onRequest(chunk, next) {
        return __awaiter(this, void 0, void 0, function* () {
            next(Object.assign(Object.assign({}, chunk), { retryCount: 0 }));
        });
    }
    retry(chunk) {
        if (this.configuration.logger)
            this.configuration.logger(chunk.retryCount + 1);
        this.request({
            retryCount: chunk.retryCount + 1,
            cb: chunk.cb,
            key: chunk.key,
            id: chunk.id,
            requestOptions: chunk.requestOptions
        });
    }
    shouldRetry(chunk) {
        const statusCode = chunk.response ? chunk.response.statusCode : null;
        if (statusCode && (statusCode === 429 || (500 <= statusCode && statusCode < 600))) {
            return true;
        }
        if (chunk.error) {
            return RETRYABLE_ERRORS.includes(chunk.error.code);
        }
        return false;
    }
}
exports.Retry = Retry;
//# sourceMappingURL=retry.js.map