"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SchemaStringifier = void 0;
const streamer_1 = require("./streamer");
const fast_json_stringify_1 = __importDefault(require("fast-json-stringify"));
class SchemaStringifier extends streamer_1.Streamer {
    constructor(configuration, stringifier = fast_json_stringify_1.default) {
        super("schema" /* StreamType.SCHEMA_STRINGIFIER */);
        this.stringifier = stringifier(configuration);
    }
    onRequest(chunk, next) {
        if (chunk.requestOptions.json && typeof chunk.requestOptions.body === "object") {
            chunk.requestOptions.json = false;
            chunk.requestOptions.headers = Object.assign({ 'content-type': 'application/json' }, chunk.requestOptions.headers);
            chunk.requestOptions.body = this.stringifier(chunk.requestOptions.body);
        }
        next(chunk);
    }
    onResponse(chunk, next) {
        if (chunk.response && chunk.response.body && typeof chunk.response.body === "string") {
            try {
                chunk.response.body = JSON.parse(chunk.response.body);
            }
            catch (e) {
                chunk.response.body = null;
            }
        }
        next(chunk);
    }
}
exports.SchemaStringifier = SchemaStringifier;
//# sourceMappingURL=schema-stringifier.js.map