"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StreamFactory = exports.ConfigurableStream = void 0;
const network_1 = require("./network");
const stream_head_1 = require("./stream-head");
const holder_1 = require("./holder");
const retry_1 = require("./retry");
const schema_stringifier_1 = require("./schema-stringifier");
var ConfigurableStream;
(function (ConfigurableStream) {
    ConfigurableStream["HOLDER"] = "holder";
    ConfigurableStream["CACHE"] = "cache";
    ConfigurableStream["SCHEMA_STRINGIFIER"] = "schema";
    ConfigurableStream["RETRY"] = "retry";
})(ConfigurableStream || (ConfigurableStream = {}));
exports.ConfigurableStream = ConfigurableStream;
class StreamFactory {
    constructor(cacheFactory) {
        this.cacheFactory = cacheFactory;
    }
    create(streamType, configuration) {
        switch (streamType) {
            case "cache" /* StreamType.CACHE */:
                return this.cacheFactory.create(configuration);
            case "holder" /* StreamType.HOLDER */:
                return new holder_1.Holder();
            case "retry" /* StreamType.RETRY */:
                return retry_1.Retry.create(configuration);
            case "schema" /* StreamType.SCHEMA_STRINGIFIER */:
                return new schema_stringifier_1.SchemaStringifier(configuration);
            default:
                throw new Error('Unknown stream type');
        }
    }
    createNetwork(name) {
        return new network_1.Network(name);
    }
    createHead() {
        return new stream_head_1.StreamHead();
    }
}
exports.StreamFactory = StreamFactory;
//# sourceMappingURL=stream-factory.js.map