"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StreamLogger = exports.LOG_COLORS = void 0;
const chalk_1 = __importDefault(require("chalk"));
const LOG_COLORS = {
    responseFailed: chalk_1.default.bold.bgRed.black,
    responseSuccessful: chalk_1.default.bold.bgGreen.black,
    requestNoStatus: chalk_1.default.bold.yellow
};
exports.LOG_COLORS = LOG_COLORS;
class StreamLogger {
    static onRequest(chunk, currentHandler, previousStream, nextStream) {
        const keyText = StreamLogger.getKeyColor(chunk)(StreamLogger.getKeyString(chunk));
        if (previousStream) {
            console.info(keyText, previousStream.name, '--->', currentHandler.name);
        }
        else {
            console.info(keyText, '|--->', currentHandler.name);
        }
    }
    static onResponse(chunk, currentHandler, previousStream, nextStream) {
        const keyText = StreamLogger.getKeyColor(chunk)(StreamLogger.getKeyString(chunk));
        if (nextStream) {
            console.info(keyText, currentHandler.name, '<---', nextStream.name);
        }
        else {
            console.info(keyText, currentHandler.name, '<---|');
        }
    }
    static getKeyColor(chunk) {
        if (chunk.error)
            return LOG_COLORS.responseFailed;
        if (chunk.response)
            return LOG_COLORS.responseSuccessful;
        return LOG_COLORS.requestNoStatus;
    }
    static getKeyString(chunk) {
        return `${chunk.id} | ${chunk.key}:`;
    }
}
exports.StreamLogger = StreamLogger;
//# sourceMappingURL=stream-logger.js.map