"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Streamer = void 0;
const stream_logger_1 = require("./stream-logger");
const warden_1 = require("./warden");
class Streamer {
    constructor(name) {
        this.name = name;
        this._onRequest = this._onRequest.bind(this);
        this._onResponse = this._onResponse.bind(this);
    }
    connect(wardenStream) {
        this.nextStream = wardenStream;
        wardenStream.previousStream = this;
        return wardenStream;
    }
    start(key, id, requestOptions, cb) {
        const chunk = {
            id,
            key,
            requestOptions,
            cb: cb
        };
        this._onRequest(chunk);
    }
    respond(chunk) {
        if (this.previousStream) {
            this.previousStream._onResponse(chunk);
        }
    }
    request(chunk) {
        if (this.nextStream) {
            this.nextStream._onRequest(chunk);
        }
    }
    onRequest(chunk, next) {
        if (next)
            next(chunk);
    }
    onResponse(chunk, next) {
        if (next)
            next(chunk);
    }
    _onRequest(chunk) {
        if (warden_1.Warden.debug)
            stream_logger_1.StreamLogger.onRequest(chunk, this, this.previousStream, this.nextStream);
        this.onRequest(chunk, this.nextStream ? this.nextStream._onRequest : undefined);
    }
    _onResponse(chunk) {
        if (warden_1.Warden.debug)
            stream_logger_1.StreamLogger.onResponse(chunk, this, this.previousStream, this.nextStream);
        this.onResponse(chunk, this.previousStream ? this.previousStream._onResponse : undefined);
    }
}
exports.Streamer = Streamer;
//# sourceMappingURL=streamer.js.map